# Copyright (c) 2022 European Union.
#
# The tool was developed with the contribution of the Joint Research Centre of the European Commission.
#
# This program is free software: you can redistribute it and/or modify it under the terms of the European Union Public
# Licence, either version 1.2 of the License, or (at your option) any later version.
# You may not use this work except in compliance with the Licence.
#
# You may obtain a copy of the Licence at: https://joinup.ec.europa.eu/collection/eupl/eupl-guidelines-faq-infographics
#
# Unless required by applicable law or agreed to in writing, software distributed under the Licence is distributed on
# an "AS IS" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#
# See the Licence for the specific language governing permissions and limitations under the Licence.

import argparse

import rasterio
import richdem as rd


def parse_args():
    parser = argparse.ArgumentParser(description='Run richdem FillDepressions on the input dem.')
    parser.add_argument('dem_in')
    parser.add_argument('dem_out')

    return parser.parse_args()


def main():
    args = parse_args()

    with rasterio.open(args.dem_in, 'r') as ds:
        dem = rd.rdarray(ds.read(1), no_data=-9999)
        profile = ds.profile

    rd.FillDepressions(dem, epsilon=True, in_place=True)
    with rasterio.open(args.dem_out, 'w', **profile) as ds:
        ds.write(dem, 1)


if __name__ == '__main__':
    main()
