# Copyright (c) 2022 European Union.
#
# The tool was developed with the contribution of the Joint Research Centre of the European Commission.
#
# This program is free software: you can redistribute it and/or modify it under the terms of the European Union Public
# Licence, either version 1.2 of the License, or (at your option) any later version.
# You may not use this work except in compliance with the Licence.
#
# You may obtain a copy of the Licence at: https://joinup.ec.europa.eu/collection/eupl/eupl-guidelines-faq-infographics
#
# Unless required by applicable law or agreed to in writing, software distributed under the Licence is distributed on
# an "AS IS" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#
# See the Licence for the specific language governing permissions and limitations under the Licence.

"""Remove member states for which ratio export / NAI contains outliers in JRC wood provision calculation from Eurostat
for_sup_cp table."""

import argparse

import pandas as pd

import inca.common.estat as estat
from inca.woodprovision import FOREST_TREES, MIO_EUR


def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument('for_sup_cp', help='Original TSV file from Eurostat.', metavar='TSV')
    parser.add_argument('output', help='Filename for resulting adjusted file.')

    return parser.parse_args()


def main():
    args = parse_args()

    for_sup_cp = estat.read_tsv(args.for_sup_cp)

    for ms in ['HR', 'FI', 'EL', 'PT', 'SE']:
        for_sup_cp.loc[MIO_EUR, FOREST_TREES, ms] = pd.NA

    estat.write_tsv(for_sup_cp, args.output)


if __name__ == '__main__':
    main()
